==> crm-commom-1.1.7.2.release.jar: com/biz/crm/eunm/activiti/ColumnStr.java <==
package com.biz.crm.eunm.activiti;

import org.apache.commons.lang3.StringUtils;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * Created by weston on 2017/5/7.
 */
public enum ColumnStr {
    //
    PROCESS_BTN(IndicatorStr.PROCESS_BTN_FILE_SELECT, IndicatorStr.PROCESS_BTN_FILE_UPLOAD, IndicatorStr.PROCESS_BTN_ISSUE,
            IndicatorStr.PROCESS_BTN_APPROVAL, IndicatorStr.PROCESS_BTN_REJECT_LAST, IndicatorStr.PROCESS_BTN_REJECT_FIRST,
            IndicatorStr.PROCESS_BTN_SAVE, IndicatorStr.PROCESS_BTN_SAVE_TODO, IndicatorStr.PROCESS_BTN_FORWARD,
            IndicatorStr.PROCESS_BTN_TURN, IndicatorStr.PROCESS_BTN_DISTRIBUTE, IndicatorStr.PROCESS_BTN_ADD,
            IndicatorStr.PROCESS_BTN_GETBACK, IndicatorStr.PROCESS_BTN_START, IndicatorStr.PROCESS_BTN_END,
            IndicatorStr.PROCESS_BTN_SUBMIT, IndicatorStr.PROCESS_BTN_CANCEL, IndicatorStr.PROCESS_BTN_INFORM,
            IndicatorStr.PROCESS_BTN_RELATIVE, IndicatorStr.PROCESS_BTN_JOINT, IndicatorStr.PROCESS_BTN_NOPASS,
            IndicatorStr.PROCESS_BTN_REJECT_END, IndicatorStr.PROCESS_BTN_CONFIRM, IndicatorStr.PROCESS_BTN_INTERVENE_POINT,
            IndicatorStr.PROCESS_BTN_ADD_MSG, IndicatorStr.PROCESS_BTN_REPLAY_MSG, IndicatorStr.PROCESS_BTN_RELATIVE_DOC,
            IndicatorStr.PROCESS_BTN_AUDIT, IndicatorStr.PROCESS_BTN_KNOWN, IndicatorStr.PROCESS_BTN_KILL, IndicatorStr.PROCESS_BTN_PRINT,
            IndicatorStr.PROCESS_BTN_URGE, IndicatorStr.PROCESS_BTN_DISAPPROVAL),
    //监听器值类型
    LISTENER_VALUE_TYPE(IndicatorStr.LISTENER_VALUE_TYPE_EXPRESSION, IndicatorStr.LISTENER_VALUE_TYPE_JAVA_CLASS),

//    FORM_TYPE(IndicatorStr.FORM_TYPE_APPLY,IndicatorStr.FORM_TYPE_REGIST,IndicatorStr.FORM_TYPE_PAY,
//            IndicatorStr.FORM_TYPE_REPORTED, IndicatorStr.FORM_TYPE_SFA, IndicatorStr.FORM_TYPE_PACT_AUDIT,
//            IndicatorStr.FORM_TYPE_IMS,IndicatorStr.FORM_TYPE_DMS, IndicatorStr.FORM_TYPE_FICO,
//            IndicatorStr.FORM_TYPE_FORM_ENGINE, IndicatorStr.FORM_TYPE_SMP,IndicatorStr.FORM_TYPE_TRADE,IndicatorStr.FORM_TYPE_HRPR),
//
//    COST_TYPE(IndicatorStr.COST_TYPE_LEADER_JY,IndicatorStr.COST_TYPE_COMMON_JY),

    SFA_SERVER(IndicatorStr.SFA_SERVER_MANAGE, IndicatorStr.SFA_SERVER_MDM),

    MSG_TYPE(IndicatorStr.MSG_TYPE_PROCESS_TASK_NOTICE, IndicatorStr.MSG_TYPE_PROCESS_REPLAY,
            IndicatorStr.MSG_TYPE_PROCESS_ADD, IndicatorStr.MSG_TYPE_PROCESS_NOTICE, IndicatorStr.MSG_TYPE_FORM_NOTICE),
    ;
    private Map<String, String> maps = new LinkedHashMap<>();

    ColumnStr(IndicatorStr... values) {
        for (IndicatorStr it : values) {
            maps.put(it.getCode(), it.getLabel());
        }
    }

    public String getLabelByCode(String code) {
        if (StringUtils.isEmpty(code)) {
            return null;
        } else {
            return maps.get(code);
        }
    }


    public Map<String, String> getCodesAndLabels() {
        return maps;
    }

}

==> crm-commom-1.1.8.2.release.jar: com/biz/crm/eunm/activiti/ColumnStr.java <==
package com.biz.crm.eunm.activiti;

import org.apache.commons.lang3.StringUtils;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * Created by weston on 2017/5/7.
 */
public enum ColumnStr {
    //
    PROCESS_BTN(IndicatorStr.PROCESS_BTN_FILE_SELECT, IndicatorStr.PROCESS_BTN_FILE_UPLOAD, IndicatorStr.PROCESS_BTN_ISSUE,
            IndicatorStr.PROCESS_BTN_APPROVAL, IndicatorStr.PROCESS_BTN_REJECT_LAST, IndicatorStr.PROCESS_BTN_REJECT_FIRST,
            IndicatorStr.PROCESS_BTN_SAVE, IndicatorStr.PROCESS_BTN_SAVE_TODO, IndicatorStr.PROCESS_BTN_FORWARD,
            IndicatorStr.PROCESS_BTN_TURN, IndicatorStr.PROCESS_BTN_DISTRIBUTE, IndicatorStr.PROCESS_BTN_ADD,
            IndicatorStr.PROCESS_BTN_GETBACK, IndicatorStr.PROCESS_BTN_START, IndicatorStr.PROCESS_BTN_END,
            IndicatorStr.PROCESS_BTN_SUBMIT, IndicatorStr.PROCESS_BTN_CANCEL, IndicatorStr.PROCESS_BTN_INFORM,
            IndicatorStr.PROCESS_BTN_RELATIVE, IndicatorStr.PROCESS_BTN_JOINT, IndicatorStr.PROCESS_BTN_NOPASS,
            IndicatorStr.PROCESS_BTN_REJECT_END, IndicatorStr.PROCESS_BTN_CONFIRM, IndicatorStr.PROCESS_BTN_INTERVENE_POINT,
            IndicatorStr.PROCESS_BTN_ADD_MSG, IndicatorStr.PROCESS_BTN_REPLAY_MSG, IndicatorStr.PROCESS_BTN_RELATIVE_DOC,
            IndicatorStr.PROCESS_BTN_AUDIT, IndicatorStr.PROCESS_BTN_KNOWN, IndicatorStr.PROCESS_BTN_KILL, IndicatorStr.PROCESS_BTN_PRINT,
            IndicatorStr.PROCESS_BTN_URGE, IndicatorStr.PROCESS_BTN_DISAPPROVAL),
    //监听器值类型
    LISTENER_VALUE_TYPE(IndicatorStr.LISTENER_VALUE_TYPE_EXPRESSION, IndicatorStr.LISTENER_VALUE_TYPE_JAVA_CLASS),

    FORM_TYPE(IndicatorStr.FORM_TYPE_SFA, IndicatorStr.FORM_TYPE_TPM, IndicatorStr.FORM_TYPE_DMS),

//    COST_TYPE(IndicatorStr.COST_TYPE_LEADER_JY,IndicatorStr.COST_TYPE_COMMON_JY),



    MSG_TYPE(IndicatorStr.MSG_TYPE_PROCESS_TASK_NOTICE, IndicatorStr.MSG_TYPE_PROCESS_REPLAY,
            IndicatorStr.MSG_TYPE_PROCESS_ADD, IndicatorStr.MSG_TYPE_PROCESS_NOTICE, IndicatorStr.MSG_TYPE_FORM_NOTICE),
    ;
    private Map<String, String> maps = new LinkedHashMap<>();

    ColumnStr(IndicatorStr... values) {
        for (IndicatorStr it : values) {
            maps.put(it.getCode(), it.getLabel());
        }
    }

    public String getLabelByCode(String code) {
        if (StringUtils.isEmpty(code)) {
            return null;
        } else {
            return maps.get(code);
        }
    }


    public Map<String, String> getCodesAndLabels() {
        return maps;
    }

}
